@@ -1,7 +1,7 @@
 /* mpfr_sub_d -- subtract a machine double precision float from
                  a multiple precision floating-point number
 
-Copyright 2007-2018 Free Software Foundation, Inc.
+Copyright 2007-2023 Free Software Foundation, Inc.
 Contributed by the AriC and Caramba projects, INRIA.
 
 This file is part of the GNU MPFR Library.
@@ -18,7 +18,7 @@ License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
-http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
+https://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
 #include "mpfr-impl.h"
@@ -32,9 +32,9 @@ mpfr_sub_d (mpfr_ptr a, mpfr_srcptr b, double c, mpfr_rnd_t rnd_mode)
   MPFR_SAVE_EXPO_DECL (expo);
 
   MPFR_LOG_FUNC
-    (("b[%Pu]=%.*Rg c=%.20g rnd=%d",
+    (("b[%Pd]=%.*Rg c=%.20g rnd=%d",
       mpfr_get_prec (b), mpfr_log_prec, b, c, rnd_mode),
-     ("a[%Pu]=%.*Rg", mpfr_get_prec (a), mpfr_log_prec, a));
+     ("a[%Pd]=%.*Rg", mpfr_get_prec (a), mpfr_log_prec, a));
 
   MPFR_SAVE_EXPO_MARK (expo);
 
