@@ -1,6 +1,6 @@
 /* Functions to work with unbounded floats (limited low-level interface).
 
-Copyright 2016-2022 Free Software Foundation, Inc.
+Copyright 2016-2023 Free Software Foundation, Inc.
 Contributed by the AriC and Caramba projects, INRIA.
 
 This file is part of the GNU MPFR Library.
@@ -74,10 +74,10 @@ void
 mpfr_ubf_mul_exact (mpfr_ubf_ptr a, mpfr_srcptr b, mpfr_srcptr c)
 {
   MPFR_LOG_FUNC
-    (("b[%Pu]=%.*Rg c[%Pu]=%.*Rg",
+    (("b[%Pd]=%.*Rg c[%Pd]=%.*Rg",
       mpfr_get_prec (b), mpfr_log_prec, b,
       mpfr_get_prec (c), mpfr_log_prec, c),
-     ("a[%Pu]=%.*Rg",
+     ("a[%Pd]=%.*Rg",
       mpfr_get_prec ((mpfr_ptr) a), mpfr_log_prec, a));
 
   MPFR_ASSERTD ((mpfr_ptr) a != b);
@@ -149,9 +149,15 @@ mpfr_ubf_mul_exact (mpfr_ubf_ptr a, mpfr_srcptr b, mpfr_srcptr c)
         }
       else
         {
-          u = (bn >= cn) ?
-            mpn_mul (ap, MPFR_MANT (b), bn, MPFR_MANT (c), cn) :
-            mpn_mul (ap, MPFR_MANT (c), cn, MPFR_MANT (b), bn);
+          if (b == c)
+            {
+              mpn_sqr (ap, MPFR_MANT (b), bn);
+              u = ap[2 * bn - 1];
+            }
+          else
+            u = (bn >= cn) ?
+              mpn_mul (ap, MPFR_MANT (b), bn, MPFR_MANT (c), cn) :
+              mpn_mul (ap, MPFR_MANT (c), cn, MPFR_MANT (b), bn);
           if (MPFR_LIMB_MSB (u) == 0)
             {
               m = 1;
